from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.configuration import zconf
from Products.validation import V_REQUIRED
from Products.ATContentTypes.content.image import ATImage

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

title_field = [
        fields.StringField(
            name='title',
            required=False,
            searchable=True,
            default='',
            accessor='Title',
            widget=widgets.StringWidget(
                label_msgid='label_title',
                visible={'view' : 'invisible'},
                i18n_domain='plone',
            ),
        ),]

class ImageExtender(DefaultExtender):
    adapts(ATImage)

    fields = DefaultExtender.fields + title_field + [
        fields.ImageField('image',
            required=True,
# we got an error with this attribute on Plone 3.3
# Tried to add 'text___fr___' as primary field but <Products.Archetypes.Schema.Schema object at 0x0AE1BBD0> already has the primary field 'text'
#
# we need the primary marker here to have multilanguage images working
            primary=True,
            languageIndependent=False,
            storage = AnnotationStorage(migrate=True),
            swallowResizeExceptions = zconf.swallowImageResizeExceptions.enable,
            pil_quality = zconf.pil_config.quality,
            pil_resize_algo = zconf.pil_config.resize_algo,
            max_size = zconf.ATImage.max_image_dimension,
            sizes= {'large'   : (768, 768),
                    'preview' : (400, 400),
                    'mini'    : (200, 200),
                    'thumb'   : (128, 128),
                    'tile'    :  (64, 64),
                    'icon'    :  (32, 32),
                    'listing' :  (16, 16),
                    },
            widget = widgets.ImageWidget(
                description = '',
                label= _(u'label_image', default=u'Image'),
                show_content_type = False,
            )
        ),
    ]

try:
    from zope.interface import implements
    from plone.app.blob.interfaces import IATBlobImage
    from archetypes.schemaextender.interfaces import ISchemaModifier
    from plone.app.imaging.interfaces import IImageScaleHandler
    
    class BlobImageExtender(DefaultExtender):
        adapts(IATBlobImage)

        fields = DefaultExtender.fields + title_field
        
    class BlobImageModifier(object):
        adapts(IATBlobImage)
        implements(ISchemaModifier)
        
        field = fields.BlobImageField('image',
                    required = True,
                    primary = True,
                    accessor = 'getImage',
                    mutator = 'setImage',
                    languageIndependent = True,
                    storage = AnnotationStorage(migrate=True),
                    swallowResizeExceptions = zconf.swallowImageResizeExceptions.enable,
                    pil_quality = zconf.pil_config.quality,
                    pil_resize_algo = zconf.pil_config.resize_algo,
                    max_size = zconf.ATImage.max_image_dimension,
                    validators = (('isNonEmptyFile', V_REQUIRED),
                                  ('checkImageMaxSize', V_REQUIRED)),
                    widget = widgets.ImageWidget(
                        description = '',
                        label=_(u'label_image', default=u'Image'),
                        show_content_type = False,
                    )
                )
        
        def __init__(self, context):
            self.context = context
            
        def fiddle(self, schema):
            schema['image'] = self.field
            return schema
except ImportError:
    pass



import unittest
import doctest

from Testing import ZopeTestCase
from zope.testing import doctestunit
from zope.component import testing, eventtesting

from Testing import ZopeTestCase as ztc
from Products.PloneTestCase import ptc

from raptus.multilanguageplone.tests import base


def test_suite():
    suite = unittest.TestSuite()

    suite.addTest(
        ztc.FunctionalDocFileSuite(
            'README.txt', 
            package='raptus.multilanguageplone',
            test_class=base.FunctionalTestCase,
            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE |
                doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS
        )
    )

    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')



from archetypes.schemaextender.field import ExtensionField
from raptus.multilanguagefields import fields

class StringField(ExtensionField, fields.StringField):
    """ StringField
    """

class LinesField(ExtensionField, fields.LinesField):
    """ LinesField
    """

class TextField(ExtensionField, fields.TextField):
    """ TextField
    """

class FileField(ExtensionField, fields.FileField):
    """ FileField
    """

class ImageField(ExtensionField, fields.ImageField):
    """ FileField
    """

try:
    class BlobFileField(ExtensionField, fields.BlobFileField):
        """ BlobFileField
        """
    
    class BlobImageField(ExtensionField, fields.BlobImageField):
        """ BlobImageField
        """
except:
    pass


from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.configuration import zconf
from Products.ATContentTypes.content.document import ATDocumentBase
from Products.ATContentTypes.content.newsitem import ATNewsItem

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

class NewsItemExtender(DefaultExtender):
    adapts(ATNewsItem)

    fields = DefaultExtender.fields + [
        fields.TextField('text',
            required = False,
            searchable = True,
# we got an error with this attribute on Plone 3.3
# Tried to add 'text___fr___' as primary field but <Products.Archetypes.Schema.Schema object at 0x0AE1BBD0> already has the primary field 'text'
#
# we need the primary markers to have the getContentType method working
            primary=True,
            storage = AnnotationStorage(migrate=True),
            default_output_type = 'text/x-html-safe',
            widget = widgets.RichWidget(
                description = '',
                label = _(u'label_body_text', u'Body Text'),
                rows = 25,
                allow_file_upload = zconf.ATDocument.allow_document_upload
            ),
            schemata='default',
        ),
        fields.ImageField('image',
            required = False,
            storage = AnnotationStorage(migrate=True),
            languageIndependent = True,
            max_size = zconf.ATNewsItem.max_image_dimension,
            sizes= {'large'   : (768, 768),
                    'preview' : (400, 400),
                    'mini'    : (200, 200),
                    'thumb'   : (128, 128),
                    'tile'    :  (64, 64),
                    'icon'    :  (32, 32),
                    'listing' :  (16, 16),
                   },
            widget = widgets.ImageWidget(
                description = _(u'help_news_image', default=u'Will be shown in the news listing, and in the news item itself. Image will be scaled to a sensible size.'),
                label= _(u'label_news_image', default=u'Image'),
                show_content_type = False
            )
        ),
        fields.StringField('imageCaption',
            required = False,
            searchable = True,
            widget = widgets.StringWidget(
                description = '',
                label = _(u'label_image_caption', default=u'Image Caption'),
                size = 40
            )
        ),
    ]

from raptus.multilanguagefields.patches.traverse import __bobo_traverse__
ATNewsItem.__bobo_traverse__ = __bobo_traverse__


from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _
from Products.validation import V_REQUIRED

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.content.file import ATFile

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

title_field = [
        fields.StringField(
            name='title',
            required=False,
            searchable=True,
            default='',
            accessor='Title',
            widget=widgets.StringWidget(
                label_msgid='label_title',
                visible={'view' : 'invisible'},
                i18n_domain='plone',
            ),
        ),]

class FileExtender(DefaultExtender):
    adapts(ATFile)

    fields = DefaultExtender.fields + title_field + [
        fields.FileField('file',
            required=True,
# we got an error with this attribute on Plone 3.3
# Tried to add 'text___fr___' as primary field but <Products.Archetypes.Schema.Schema object at 0x0AE1BBD0> already has the primary field 'text'
#
# we need the primary marker here to have multilanguage files working
            primary=True,
            searchable=True,
            languageIndependent=False,
            storage = AnnotationStorage(migrate=True),
            widget = widgets.FileWidget(
                description = '',
                label=_(u'label_file', default=u'File'),
                show_content_type = False,
            )
        ),
    ]

try:
    from zope.interface import implements
    from plone.app.blob.interfaces import IATBlobFile
    from archetypes.schemaextender.interfaces import ISchemaModifier
    
    class BlobFileExtender(DefaultExtender):
        adapts(IATBlobFile)
    
        fields = DefaultExtender.fields + title_field

    class BlobFileModifier(object):
        adapts(IATBlobFile)
        implements(ISchemaModifier)
        
        field = fields.BlobFileField('file',
                    required = True,
                    primary = True,
                    searchable = True,
                    accessor = 'getFile',
                    mutator = 'setFile',
                    index_method = 'getIndexValue',
                    languageIndependent = True,
                    storage = AnnotationStorage(migrate=True),
                    validators = (('isNonEmptyFile', V_REQUIRED),
                                  ('checkFileMaxSize', V_REQUIRED)),
                    widget = widgets.FileWidget(
                        description = '',
                        label=_(u'label_file', default=u'File'),
                        show_content_type = False,
                    )
                )
        
        def __init__(self, context):
            self.context = context
            
        def fiddle(self, schema):
            schema['file'] = self.field
            return schema
except:
    pass



from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.content.link import ATLink

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

class LinkExtender(DefaultExtender):
    adapts(ATLink)

    fields = DefaultExtender.fields + [
        fields.StringField('remoteUrl',
            required=True,
            searchable=True,
            primary=True,
            default = "http://",
            # either mailto, absolute url or relative url
            validators = (),
            widget = widgets.StringWidget(
                description = '',
                label = _(u'label_url', default=u'URL')
            )
        ),
    ]


from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.configuration import zconf
from Products.ATContentTypes.content.document import ATDocument

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

class DocumentExtender(DefaultExtender):
    adapts(ATDocument)

    fields = DefaultExtender.fields + [
        fields.TextField('text',
                  required=False,
                  searchable=True,
# we got an error with this attribute on Plone 3.3
# Tried to add 'text___fr___' as primary field but <Products.Archetypes.Schema.Schema object at 0x0AE1BBD0> already has the primary field 'text'
#
# we need the primary markers to have the getContentType method working
                  primary=True,
                  storage = AnnotationStorage(migrate=True),
                  default_output_type = 'text/x-html-safe',
                  widget = widgets.RichWidget(
                            description = '',
                            label = _(u'label_body_text', default=u'Body Text'),
                            rows = 25,
                            allow_file_upload = zconf.ATDocument.allow_document_upload),
                  schemata='default',
        ),
    ]


from zope.component import adapts
from Products.Archetypes import PloneMessageFactory as _

from Products.Archetypes.atapi import AnnotationStorage
from Products.ATContentTypes.configuration import zconf
from Products.ATContentTypes.content.event import ATEvent
from Products.ATContentTypes.permission import ChangeEvents

from raptus.multilanguagefields import widgets
import fields

from base import DefaultExtender

class EventExtender(DefaultExtender):
    adapts(ATEvent)

    fields = DefaultExtender.fields + [
        fields.StringField('location',
            searchable=True,
            write_permission = ChangeEvents,
            widget = widgets.StringWidget(
                description = '',
                label = _(u'label_event_location', default=u'Event Location')
            )
        ),
        fields.TextField('text',
            required=False,
            searchable=True,
# we got an error with this attribute on Plone 3.3
# Tried to add 'text___fr___' as primary field but <Products.Archetypes.Schema.Schema object at 0x0AE1BBD0> already has the primary field 'text'
#
# we need the primary markers to have the getContentType method working
            primary=True,
            storage = AnnotationStorage(migrate=True),
            default_output_type = 'text/x-html-safe',
            widget = widgets.RichWidget(
                description = '',
                label = _(u'label_event_announcement', default=u'Event body text'),
                rows = 25,
                allow_file_upload = zconf.ATDocument.allow_document_upload
            ),
            schemata='default',
        ),
    ]


from Products.CMFCore.utils import getToolByName

def uninstall(portal):
    setup_tool = getToolByName(portal, 'portal_setup')
    setup_tool.runAllImportStepsFromProfile('profile-raptus.multilanguageplone:uninstall')


from zope.interface import implements
from archetypes.schemaextender.interfaces import ISchemaExtender
from Products.Archetypes import PloneMessageFactory as _

from raptus.multilanguagefields import widgets
import fields

class DefaultExtender(object):
    implements(ISchemaExtender)

    fields = [
        fields.StringField(
            name='title',
            required=1,
            searchable=1,
            default='',
            accessor='Title',
            widget=widgets.StringWidget(
                label = _(u'label_title', default=u'Title'),
                visible={'view' : 'invisible'},
                i18n_domain='plone',
            ),
            schemata='default',
        ),
        fields.LinesField(
            'subject',
            multiValued=1,
            accessor="Subject",
            searchable=True,
            isMetadata=True,
            widget=widgets.KeywordWidget(
                label=_(u'label_categories', default=u'Categories'),
                description=_(u'help_categories',
                              default=u'Also known as keywords, tags or labels, '
                                       'these help you categorize your content.'),
            ),
            schemata='categorization',
        ),
        fields.TextField(
            'description',
            default='',
            searchable=1,
            accessor="Description",
            default_content_type = 'text/plain',
            allowable_content_types = ('text/plain',),
            widget=widgets.TextAreaWidget(
                label=_(u'label_description', default=u'Description'),
                description=_(u'help_description',
                              default=u'A short summary of the content.'),
            ),
            schemata='default',
        ),
        fields.TextField(
            'rights',
            accessor="Rights",
            isMetadata=True,
            default_method='defaultRights',
            widget=widgets.TextAreaWidget(
                label=_(u'label_copyrights', default=u'Rights'),
                description=_(u'help_copyrights',
                              default=u'Copyright statement or other rights information on this item.'),
            ),
            schemata='ownership',
        ),
    ]

    def __init__(self, context):
         self.context = context

    def getFields(self):
        return self.fields



from archetypes.schemaextender.interfaces import ISchemaExtender

from raptus.multilanguageplone.extender import folder, document, event, file, image, link, newsitem, topic

from Products.CMFCore.utils import getToolByName

extenders = [folder.FolderExtender,
             document.DocumentExtender,
             event.EventExtender,
             file.FileExtender,
             image.ImageExtender,
             link.LinkExtender,
             newsitem.NewsItemExtender,
             topic.TopicExtender,]

try:
    from raptus.multilanguageplone.extender.file import BlobFileExtender, BlobFileModifier
    extenders.append(BlobFileExtender)
    extenders.append(BlobFileModifier)
    from raptus.multilanguageplone.extender.image import BlobImageExtender, BlobImageModifier
    extenders.append(BlobImageExtender)
    extenders.append(BlobImageModifier)
except ImportError:
    pass

indexes = ('SearchableText', 'Subject', 'Title', 'Description', 'sortable_title',)

def reindex(portal):
    catalog = getToolByName(portal, 'portal_catalog')
    for index in indexes:
        catalog.reindexIndex(index, portal.REQUEST)

def install(context):
    if context.readDataFile('raptus.multilanguageplone_install.txt') is None:
        return
    portal = context.getSite()
    
    sm = portal.getSiteManager()
    for extender in extenders:
        sm.registerAdapter(extender, name='Multilanguage%s' % extender.__name__)
    
    reindex(portal)
    
def uninstall(context):
    if context.readDataFile('raptus.multilanguageplone_install.txt') is None and \
       context.readDataFile('raptus.multilanguageplone_uninstall.txt') is None:
        return
    
    portal = context.getSite()
    
    sm = portal.getSiteManager()
    for extender in extenders:
        try:
            sm.unregisterAdapter(extender, name='Multilanguage%s' % extender.__name__)
        except:
            pass
        
    reindex(portal)
    


from zope.component import adapts
try:
    from plone.app.folder.folder import ATFolder
except:
    from Products.ATContentTypes.content.folder import ATFolder

from base import DefaultExtender

class FolderExtender(DefaultExtender):
    adapts(ATFolder)